<section class="module" style="display:inline-block">
<h2>{{_('Edit and Remove Tags')}}</h2>
	<div class="module-content">
		<ul style="list-style=none">
		{% set tl = h.tagmanager_list_tags() %}
	    {% for tag in tl %}
		<li style="display:inline; position:relative">
			<div style='float:left'>{{ h.link_to(tag.display_name + ' (' + h.tagmanager_tag_show(tag.id).packages|count|string + ')', h.url_for(controller='package', action='search', tags= tag.name), class_='tag') }} {#h.url_for(controller='tagmanager', action='delete_confirm')#} <a href="/tagmanager/delete_confirm?tag={{tag.id}}" class="tag_remove" title="{{_('Remove tag ') + tag.name}}">x</a>
			</div>
		</li>
		{% endfor %}
		</ul>
	</div>
</section>
