{% extends "page.html" %}

{% block subtitle %}{{ _("Tag Manager") }}{% endblock %}

{% block breadcrumb_content %}
  <li class="active">{{ h.nav_link(_('Tags Manager'), controller='package', action='search', highlight_actions = 'new index') }}</li>
{% endblock %}

{% block page_header %}{% endblock %}

{% block primary_content_inner %}
	
	<h1 class="hide-heading">{{ _('Tags') }}</h1>
	{% if h.check_access('group_create') %} <!-- TODO Tag create access! -->
	  
		{% block tags_list_with_remove %}
			{% snippet "tagmanager/snippets/tags_list_with_remove.html" %}
		{% endblock %}	
	  
	{% else %}
		{% block tags_list %}
			 {% snippet "tagmanager/snippets/tags_list.html" %}
		{% endblock %}

	{% endif %} <!-- tag create access -->
{% endblock %} <!--primary content inner -->

{% block secondary_content %}
  {% snippet "group/snippets/helper.html" %}
{% endblock %}

