{% ckan_extends %}

      {% block header_site_navigation %}
        <nav class="section navigation">
          <ul class="nav nav-pills">
            {% block header_site_navigation_tabs %}
              {{ h.build_nav_main(
                ('search', _('Datasets')),
                ('organizations_index', _('Organizations')),
                ('group_index', _('Groups')),
                ('/tagmanager', _('Tags')),
                ('about', _('About'))
              ) }}
            {% endblock %}
          </ul>
        </nav>
      {% endblock %}
